Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(272)

Unified Diff: chrome/browser/ui/ash/launcher/app_window_launcher_controller.h

Issue 2839933005: mash: Merge ChromeLauncherController and *Impl subclass. (Closed)
Patch Set: Address comments. Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/ash/launcher/app_window_launcher_controller.h
diff --git a/chrome/browser/ui/ash/launcher/app_window_launcher_controller.h b/chrome/browser/ui/ash/launcher/app_window_launcher_controller.h
index 75c1992775e89070e5e2ebf6ea0a6b347504d2eb..9bdb6b9b0a6b2f6cdd57f0347583feb530cbccee 100644
--- a/chrome/browser/ui/ash/launcher/app_window_launcher_controller.h
+++ b/chrome/browser/ui/ash/launcher/app_window_launcher_controller.h
@@ -20,7 +20,7 @@ class ActivationClient;
}
class AppWindowLauncherItemController;
-class ChromeLauncherControllerImpl;
+class ChromeLauncherController;
class Profile;
class AppWindowLauncherController
@@ -28,7 +28,7 @@ class AppWindowLauncherController
public:
~AppWindowLauncherController() override;
// Called by ChromeLauncherControllerImpl when the active user changed and the
// items need to be updated.
virtual void ActiveUserChanged(const std::string& user_email) {}
@@ -43,16 +43,16 @@ class AppWindowLauncherController
aura::Window* lost_active) override;
protected:
- explicit AppWindowLauncherController(ChromeLauncherControllerImpl* owner);
+ explicit AppWindowLauncherController(ChromeLauncherController* owner);
- ChromeLauncherControllerImpl* owner() { return owner_; }
+ ChromeLauncherController* owner() { return owner_; }
virtual AppWindowLauncherItemController* ControllerForWindow(
aura::Window* window) = 0;
private:
// Unowned pointers.
- ChromeLauncherControllerImpl* owner_;
+ ChromeLauncherController* owner_;
aura::client::ActivationClient* activation_client_ = nullptr;
DISALLOW_COPY_AND_ASSIGN(AppWindowLauncherController);
« no previous file with comments | « chrome/browser/ui/ash/chrome_shell_delegate.cc ('k') | chrome/browser/ui/ash/launcher/app_window_launcher_controller.cc » ('j') | no next file with comments »
@@ -28,7 +28,7 @@ class AppWindowLauncherController
public:
~AppWindowLauncherController() override;
- // Called by ChromeLauncherControllerImpl when the active user changed and the
+ // Called by ChromeLauncherController when the active user changed and the
// items need to be updated.
virtual void ActiveUserChanged(const std::string& user_email) {}

Powered by Google App Engine
This is Rietveld 408576698